==> haskell-hw-fingertree-0.1.2.1-183-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-fingertree
version:              0.1.2.1
visibility:           public
id:                   hw-fingertree-0.1.2.1-FjJKZAsVkZTJvHjkGOFTuO
key:                  hw-fingertree-0.1.2.1-FjJKZAsVkZTJvHjkGOFTuO
license:              BSD-3-Clause
copyright:
    (c) 2017-2022 John Ky
    (c) 2006 Ross Paterson, Ralf Hinze,

maintainer:           John Ky <newhoggy@gmail.com>
homepage:             https://github.com/haskell-works/hw-fingertree#readme
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  3c88e6627e7afe1d041a5735fd2105b5
exposed:              True
exposed-modules:
    HaskellWorks.Data.FingerTree
    HaskellWorks.Data.IntervalMap.FingerTree
    HaskellWorks.Data.PriorityQueue.FingerTree

hidden-modules:       Paths_hw_fingertree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-fingertree-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-fingertree
hs-libraries:         HShw-fingertree-0.1.2.1-FjJKZAsVkZTJvHjkGOFTuO
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hw-prim-0.6.3.2-EOVncZMy8n2DBSm2vvRoEz

haddock-interfaces:
    /usr/share/doc/haskell-hw-fingertree/html/hw-fingertree.haddock

haddock-html:         /usr/share/doc/haskell-hw-fingertree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-fingertree-0.1.2.1-189-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-fingertree
version:              0.1.2.1
visibility:           public
id:                   hw-fingertree-0.1.2.1-IVTYo7bBqDo1XBz707UH2X
key:                  hw-fingertree-0.1.2.1-IVTYo7bBqDo1XBz707UH2X
license:              BSD-3-Clause
copyright:
    (c) 2017-2022 John Ky
    (c) 2006 Ross Paterson, Ralf Hinze,

maintainer:           John Ky <newhoggy@gmail.com>
homepage:             https://github.com/haskell-works/hw-fingertree#readme
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  52942a0948a4e7565fa7881d4c365aaa
exposed:              True
exposed-modules:
    HaskellWorks.Data.FingerTree
    HaskellWorks.Data.IntervalMap.FingerTree
    HaskellWorks.Data.PriorityQueue.FingerTree

hidden-modules:       Paths_hw_fingertree
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hw-fingertree-0.1.2.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/hw-fingertree-0.1.2.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/hw-fingertree-0.1.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-fingertree
hs-libraries:         HShw-fingertree-0.1.2.1-IVTYo7bBqDo1XBz707UH2X
depends:
    base-4.18.3.0 deepseq-1.4.8.1
    hw-prim-0.6.3.2-5vVXhBOI4138iFakq4JCZt

haddock-interfaces:
    /usr/share/doc/haskell-hw-fingertree/html/hw-fingertree.haddock

haddock-html:         /usr/share/doc/haskell-hw-fingertree/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
